pub struct ImageRef {
pub rid: i32,
pub externally_managed: bool,
}Expand description
A reference to an image.
Fields
rid: i32The reference id of the stored image.
This property is exposed for the functions that the register_source macro generates and should not be used directly.
externally_managed: boolWhether the image is externally managed.
This property is exposed for the functions that the register_source macro generates and should not be used directly.
Implementations